import React from 'react';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';

import './NavContent.css';

export default class NavContent extends React.Component {
  getActionsItem = (item) => (
    <div className="nc-actions-item" key={item.id}>
      {item.icon ? <FontAwesomeIcon icon={item.icon} /> : null}
      <h3>{item.header}</h3>
    </div>
  );

  getActions = (content) => (
    <div className="nc-list">
      <div className="nc-list-content">
        { content.map((item) => this.getActionsItem(item)) }
      </div>
    </div>
  );

  getListContentItem = (item) => (
    <div className="nc-list-content-item" key={item.id}>
      {item.icon ? <FontAwesomeIcon icon={item.icon} /> : null}
      <h3>{item.header}</h3>
      {item.crop ? <FontAwesomeIcon icon={'caret-right'} /> : null}
    </div>
  );

  getList = (header, content, actions) => (
    <div className="nc-list">
      {
        header !== ''
          ? (
            <div className="nc-list-header">
              <h2>{header}</h2>
            </div>
          )
          : null
      }
      { actions && actions[0] ? this.getActions(actions) : null  }
      {
        content && content[0]
          ? (
            <div className="nc-list-content">
              { content.map((item) => this.getListContentItem(item)) }
            </div>
          )
          : null
      }
    </div>
  );

  getCategoriesAndRegisters = () => (
    <div>
      {
        this.getList(
          'Favorites',
          [
            {
              id: 0,
              header: 'My Cases',
              icon: 'list',
            },
            {
              id: 1,
              header: 'New Help Desk cases',
              icon: 'list',
            },
          ],
        )
      }
      {
        this.getList(
          'Job lists',
          [
            {
              id: 0,
              header: 'Development',
              crop: [
                {
                  id: 0,
                  header: 'V.7.0.0',
                  icon: 'list',
                },
                {
                  id: 1,
                  header: 'Unassigned',
                  icon: 'list',
                },
              ],
            },
            {
              id: 1,
              header: 'Help Desk',
              crop: [
                {
                  id: 0,
                  header: 'New Help Desk cases',
                  icon: 'list',
                },
                {
                  id: 1,
                  header: 'Solved',
                  icon: 'list',
                },
              ],
            },
            {
              id: 2,
              header: 'Sales',
              crop: [
                {
                  id: 0,
                  header: 'New Sales',
                  icon: 'list',
                },
                {
                  id: 1,
                  header: 'Closed Sales',
                  icon: 'list',
                },
              ],
            },
          ],
        )
      }
      {
        this.getList(
          'Registers',
          [
            {
              id: 0,
              header: 'Users',
              crop: [
                {
                  id: 0,
                  header: 'Internal Users',
                  icon: 'list',
                },
                {
                  id: 1,
                  header: 'External Users',
                  icon: 'list',
                },
              ],
            },
            {
              id: 1,
              header: 'Customers',
              crop: [
                {
                  id: 0,
                  header: 'All Users',
                  icon: 'list',
                },
              ],
            },
            {
              id: 2,
              header: 'Products',
              crop: [
                {
                  id: 0,
                  header: 'All Products',
                  icon: 'list',
                },
              ],
            },
          ],
        )
      }
    </div>
  );

  getHistory = () => {
    return (
      this.getList(
        'History',
        [
          {
            id: 0,
            header: '4220, Troublesome ticket',
            icon: 'ticket-alt',
          },
          {
            id: 1,
            header: 'All users',
            icon: 'list',
          },
          {
            id: 2,
            header: '543, Product Requeste',
            icon: 'ticket-alt',
          },
        ],
        [
          {
            id: 0,
            header: 'Clear History',
            icon: 'trash',
          },
        ],
      )
    )
  };

  getSearch = () => {
    return (
      this.getList(
        'Search',
        [],
      )
    )
  };

  getFavorites = () => {
    return (
      this.getList(
        'Favorites',
        [
          {
            id: 0,
            header: 'My tickets',
            icon: 'list',
          },
          {
            id: 1,
            header: 'New tickets',
            icon: 'list',
          },
        ],
        [
          {
            id: 0,
            header: 'Edit Favorites',
            icon: 'edit',
          },
        ],
      )
    )
  };

  getWatched = () => {
    return (
      this.getList(
        'Watched',
        [
          {
            id: 0,
            header: '4220, Troublesome ticket',
            icon: 'ticket-alt',
          },
          {
            id: 1,
            header: 'New Help Desk cases',
            icon: 'list',
          },
        ],
        [
          {
            id: 0,
            header: 'Clear All',
            icon: 'undo',
          },
          {
            id: 1,
            header: 'Settings',
            icon: 'cog',
          },
          {
            id: 2,
            header: 'What is watching?',
            icon: 'info',
          },
        ],
      )
    )
  };

  getModified = () => {
    return (
      this.getList(
        'Unsaved',
        [
          {
            id: 0,
            header: '4220, Troublesome ticket',
            icon: 'ticket-alt',
          },
        ],
        [
          {
            id: 0,
            header: 'Save All',
            icon: 'save',
          },
          {
            id: 1,
            header: 'Discard All',
            icon: 'undo',
          },
        ],
      )
    )
  };

  getModeContent = () => {
    const { mode } = this.props;
    if (mode === 0) {
      return this.getCategoriesAndRegisters();
    } else if (mode === 1) {
      return this.getHistory();
    } else if (mode === 2) {
      return this.getSearch();
    } else if (mode === 3) {
      return this.getWatched();
    } else if (mode === 4) {
      return this.getModified();
    }
    return null;
  };

  render() {
    return (
      <div className="NavContent">
        {this.getModeContent()}
      </div>
    );
  }
}
