import React from 'react';
import PaneHeader from '../components/pane/PaneHeader';
import PaneContent from '../components/pane/PaneContent';
import PaneControls from '../components/pane/PaneControls';

import './PaneContainer.css';

export default class PaneContainer extends React.Component {
  constructor() {
    super();
    this.state = {
      startX: 0,
      width: -1,
    };
    this.timeout = null;
  }

  /**
   * Start the resizing progress.
   */
  handleResizeStart = (e) => {
    e.preventDefault();
    const width = this.element.offsetWidth;
    const startX = e.clientX;
    this.setState({
      width,
      startX,
    });
    document.addEventListener('mousemove', this.handleResizeMove, false);
    document.addEventListener('mouseup', this.handleResizeStop, false);
    document.addEventListener('touchend', this.handleResizeStop, false);
  };

  /**
   * Update the container size as the user moves the cursor.
   */
  handleResizeMove = (e) => {
    e.preventDefault();
    const maxWidth = document.body.clientWidth;
    const endX = e.clientX;
    const isMovingRight = endX > this.state.startX;
    let width = isMovingRight
      ? this.state.width - (endX - this.state.startX)
      : this.state.width + (this.state.startX - endX);
    // Make sure the pane doesn't get too big or too small.
    width = width > maxWidth ? maxWidth : width;
    width = width < maxWidth/4 ? maxWidth/4 : width;
    // Update the size.
    if (width !== this.state.width) {
      // IE lags if you don't limit the updating process.
      clearTimeout(this.timeout);
      this.timeout = setTimeout(() => {
        this.setState({
          startX: endX,
          width,
        });
      }, 1);
    }
  };

  /**
   * Remove event listeners.
   */
  handleResizeStop = (e) => {
    e.preventDefault();
    document.removeEventListener('mousemove', this.handleResizeMove, false);
    document.removeEventListener('mouseup', this.handleResizeMove, false);
    document.removeEventListener('touchend', this.handleResizeMove, false);
  };

  render() {
    return (
      <div
        className="PaneContainer"
        ref={(ref) => { this.element = ref; }}
        style={{ width: this.state.width }}
      >
        <div className="pc-resize-handle"
          onMouseDown={this.handleResizeStart}
          onTouchStart={this.handleResizeStart}
        >
          <div className="pc-resize-handle-indicator" />
        </div>
        <div className="pc-content-wrapper">
          <PaneHeader title={'Internal Comment'} />
          <PaneContent />
          <PaneControls />
        </div>
      </div>
    );
  }
};
